"use strict";
var properties_1 = require("../modules/properties");
var THREE = require("three");
var OrbitControls_1 = require("../modules/OrbitControls");
var dat = require("dat-gui");
//import "../libs/OrbitControls"
document.addEventListener("DOMContentLoaded", contentLoadedHandler);
var props;
var controls;
function contentLoadedHandler() {
    var guiElt = document.getElementById("gui");
    var contentElt = document.getElementById("mycontent");
    var headerElt = document.getElementById("myhead");
    var infoElt = document.getElementById("info");
    document.title = "Three.js on Electron";
    //Title
    if (headerElt !== null) {
        headerElt.textContent = "Three js + dat.GUI Test";
        var descriptionElt = document.createElement("p");
        descriptionElt.textContent = "Drag to orbit, Mouse Wheel to Dolly.";
        if (infoElt !== null) {
            infoElt.insertBefore(descriptionElt, headerElt.nextSibling);
        }
    }
    var width = window.innerWidth;
    var height = window.innerHeight;
    //Scene,Camera,Renderer
    var scene = new THREE.Scene();
    scene.background = new THREE.Color(0x333333);
    var camera = new THREE.PerspectiveCamera(75, (width / height), 0.1, 1000);
    var renderer = new THREE.WebGLRenderer();
    renderer.setSize(width, height);
    if (contentElt !== null)
        contentElt.appendChild(renderer.domElement);
    //Teak camera position and orbit controls
    camera.position.z = 50;
    controls = new OrbitControls_1.OrbitControls(camera);
    controls.maxDistance = 100;
    controls.maxPolarAngle = Math.PI * 0.5;
    //Torusknot
    var geometry = new THREE.TorusKnotGeometry(10, 2, 100, 16);
    var material = new THREE.MeshLambertMaterial({ color: 0x00ff00, emissive: 0x225588 });
    var cube = new THREE.Mesh(geometry, material);
    scene.add(cube);
    //Light
    var light = new THREE.DirectionalLight(0xffffff, 0.5);
    scene.add(light);
    //Helper
    var axis = new THREE.AxisHelper(10.0);
    scene.add(axis);
    var gui = new dat.GUI({ autoPlace: false });
    if (guiElt !== null)
        guiElt.appendChild(gui.domElement);
    props = new properties_1.GeoProps();
    var propFolder = gui.addFolder("Geometry Properties");
    var onChangeProps = function () {
        geometry.dispose();
        cube.geometry = new THREE.TorusKnotGeometry(props.radius, props.tube, props.segment, 16);
    };
    propFolder.add(props, "radius", 1, 20).onChange(onChangeProps);
    propFolder.add(props, "tube", 0.5, 5.0).onChange(onChangeProps);
    propFolder.add(props, "segment", 5, 200).step(1).onChange(onChangeProps);
    var animate = function () {
        requestAnimationFrame(animate);
        cube.rotation.x += 0.01;
        cube.rotation.y += 0.01;
        controls.update();
        renderer.render(scene, camera);
    };
    animate();
}
module.exports = {};
