import {GeoProps} from "../modules/properties";
import * as THREE from "three";
import { OrbitControls } from "../modules/OrbitControls";
import * as dat from "dat-gui"
//import "../libs/OrbitControls"


document.addEventListener("DOMContentLoaded",contentLoadedHandler);


let props:GeoProps;
let controls:OrbitControls;

function contentLoadedHandler(){
    const guiElt:HTMLDivElement | null = document.getElementById("gui") as HTMLDivElement;
    const contentElt:HTMLDivElement | null = document.getElementById("mycontent") as HTMLDivElement;
    const headerElt:HTMLHeadingElement | null = document.getElementById("myhead") as HTMLHeadingElement;
    const infoElt:HTMLDivElement | null = document.getElementById("info") as HTMLDivElement;
    
    document.title = "Three.js on Electron";

    //Title
    if(headerElt!==null){
        headerElt.textContent = "Three js + dat.GUI Test";
        const descriptionElt:HTMLParagraphElement = document.createElement("p") as HTMLParagraphElement;
        descriptionElt.textContent = "Drag to orbit, Mouse Wheel to Dolly.";
        if(infoElt !== null){
            infoElt.insertBefore(descriptionElt,headerElt.nextSibling);
        }
    }

    let width:number = window.innerWidth;
    let height:number = window.innerHeight;
    
    //Scene,Camera,Renderer
    let scene = new THREE.Scene();
    scene.background = new THREE.Color(0x333333);
    let camera:THREE.PerspectiveCamera = new THREE.PerspectiveCamera(75,(width/height),0.1,1000);
    let renderer = new THREE.WebGLRenderer();
    renderer.setSize(width,height);
    if(contentElt!==null) contentElt.appendChild(renderer.domElement);
    
    //Teak camera position and orbit controls
    camera.position.z = 50;    
    controls = new OrbitControls(camera);
    controls.maxDistance = 100;
    controls.maxPolarAngle = Math.PI * 0.5;
    

    //Torusknot
    let geometry = new THREE.TorusKnotGeometry( 10, 2, 100, 16 );
    let material = new THREE.MeshLambertMaterial( { color: 0x00ff00,emissive:0x225588} );
    let cube = new THREE.Mesh( geometry, material );
    scene.add( cube );

    //Light
    let light = new THREE.DirectionalLight(0xffffff,0.5);
    scene.add(light);

    //Helper
    let axis:THREE.AxisHelper = new THREE.AxisHelper(10.0);
    scene.add(axis);

    

    let gui:dat.GUI = new dat.GUI({autoPlace:false});
    if(guiElt!==null) guiElt.appendChild(gui.domElement);

    props = new GeoProps();
    let propFolder = gui.addFolder("Geometry Properties");

    let onChangeProps = () =>{
        geometry.dispose();
        cube.geometry = new THREE.TorusKnotGeometry(props.radius, props.tube, props.segment,16);
    }

    propFolder.add(props,"radius", 1, 20).onChange(onChangeProps);
    propFolder.add(props, "tube",0.5,5.0).onChange(onChangeProps);
    propFolder.add(props,"segment",5,200).step(1).onChange(onChangeProps);


    let animate = ()=>{
        requestAnimationFrame(animate);
        cube.rotation.x += 0.01;
        cube.rotation.y += 0.01;
        controls.update();
        renderer.render(scene,camera);
    };

    animate();
}

export = {}